/*
CREATE DATABASE ebSQL_Test CHARACTER SET latin1 COLLATE latin1_general_ci;
*/

set GLOBAL sql_mode = 'NO_AUTO_VALUE_ON_ZERO,STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION';
SET GLOBAL log_bin_trust_function_creators = 1;



DROP TABLE if exists physical_address;
CREATE TABLE physical_address (
       addressID            Integer NOT NULL AUTO_INCREMENT,
       street               varchar(255) NULL,
       city                 varchar(50) NULL,
       phone                varchar(20) NULL,
       fax                  varchar(20) NULL,
       countryID            Integer NOT NULL,
       map                  LongBLOB NULL,
       PRIMARY KEY (addressID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;


DROP TABLE if exists address_person;
CREATE TABLE address_person (
       personID             Integer NOT NULL,
       addressID            Integer NOT NULL,
       addresstypeID        TinyInt NOT NULL,
       PRIMARY KEY (personID, addressID)
)ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;


DROP TABLE if exists address_type;
CREATE TABLE address_type (
       addresstypeID        TinyInt NOT NULL AUTO_INCREMENT,
       type_descrip         varchar(20) NULL,
       PRIMARY KEY (addresstypeID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;

DROP TABLE if exists civil_state;
CREATE TABLE civil_state (
       civilstateID         TinyInt NOT NULL AUTO_INCREMENT,
       state_descrip        varchar(30) NULL,
       PRIMARY KEY (civilstateID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;


DROP TABLE if exists country;
CREATE TABLE country (
       countryID            Integer NOT NULL AUTO_INCREMENT,
       country_name         varchar(50) NULL,    
       PRIMARY KEY (countryID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;


DROP TABLE if exists person;
CREATE TABLE person (
       personID             Integer NOT NULL AUTO_INCREMENT,
       firstname            varchar(50) NULL,
       lastname             varchar(50) NULL,
       birthdate            datetime NULL,
       email                varchar(255) NULL,
       civilstateID         TinyInt NOT NULL,
       photo                LongBLOB  NULL,
       details              LongText  NULL,
       PRIMARY KEY (personID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_general_ci;
;



ALTER TABLE physical_address  
  ADD FOREIGN KEY  (countryID)  
  REFERENCES  country (countryID);              
                              
                                                      
ALTER TABLE address_person
       ADD FOREIGN KEY (addresstypeID)
       REFERENCES address_type (addresstypeID);


ALTER TABLE address_person
       ADD FOREIGN KEY (addressID)
       REFERENCES physical_address (addressID);



ALTER TABLE address_person
       ADD FOREIGN KEY (personID)
       REFERENCES person (personID);
                      
       
ALTER TABLE person
       ADD FOREIGN KEY (civilstateID)
       REFERENCES civil_state (civilstateID);


/* Insert table civil_state*/
INSERT INTO civil_state(state_descrip) VALUES('Single');
INSERT INTO civil_state(state_descrip) VALUES('Married');
INSERT INTO civil_state(state_descrip) VALUES('divorced');
INSERT INTO civil_state(state_descrip) VALUES('widower');


/* Insert table Country*/
INSERT INTO country(country_name) VALUES('Argentina');
INSERT INTO country(country_name) VALUES('Austria');
INSERT INTO country(country_name) VALUES('Belgium');
INSERT INTO country(country_name) VALUES('Brazil');
INSERT INTO country(country_name) VALUES('Canada');
INSERT INTO country(country_name) VALUES('Denmark');
INSERT INTO country(country_name) VALUES('Finland');
INSERT INTO country(country_name) VALUES('France');
INSERT INTO country(country_name) VALUES('Germany');
INSERT INTO country(country_name) VALUES('Ireland');
INSERT INTO country(country_name) VALUES('Italy');
INSERT INTO country(country_name) VALUES('Mexico');
INSERT INTO country(country_name) VALUES('Norway');
INSERT INTO country(country_name) VALUES('Poland');
INSERT INTO country(country_name) VALUES('Portugal');
INSERT INTO country(country_name) VALUES('Spain');
INSERT INTO country(country_name) VALUES('Sweden');
INSERT INTO country(country_name) VALUES('Switzerland');
INSERT INTO country(country_name) VALUES('UK');
INSERT INTO country(country_name) VALUES('USA');
INSERT INTO country(country_name) VALUES('Venezuela');

/*Insert table address_type */
INSERT INTO address_type(type_descrip) VALUES('Personal');
INSERT INTO address_type(type_descrip) VALUES('Work');


/*Insert table physical_address*/
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Obere Str. 57','Berlin','030-0074321','030-0076545',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Avda. de la Constitucion 2222','Mexico D.F.','(5) 555-4729','(5) 555-3745',12);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Mataderos  2312','Mexico D.F.','(5) 555-3932','',12);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('120 Hanover Sq.','London','(171) 555-7788','(171) 555-6750',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Berguvsvagen  8','Lulea','0921-12 34 65','0921-12 34 67',17);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Forsterstr. 57','Mannheim','0621-08460','0621-08924',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('24, place Kleber','Strasbourg','88.60.15.31','88.60.15.32',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('C/ Araquil, 67','Madrid','(91) 555 22 82','(91) 555 91 99',16);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('12, rue des Bouchers','Marseille','91.24.45.40','91.24.45.41',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('23 Tsawassen Blvd.','Tsawassen','(604) 555-4729','(604) 555-3745',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Fauntleroy Circus','London','(171) 555-1212','',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Cerrito 333','Buenos Aires','(1) 135-5555','(1) 135-4892',1);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Sierras de Granada 9993','Mexico D.F.','(5) 555-3392','(5) 555-7293',12);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Hauptstr. 29','Bern','0452-076545','',18);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Av. dos Lusiadas, 23','Sao Paulo','(11) 555-7647','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Berkeley Gardens 12  Brewery','London','(171) 555-2282','(171) 555-9199',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Walserweg 21','Aachen','0241-039123','0241-059428',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('67, rue des Cinquante Otages','Nantes','40.67.88.88','40.67.89.89',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('35 King George','London','(171) 555-0297','(171) 555-3373',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Kirchgasse 6','Graz','7675-3425','7675-3426',2);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rua Oros, 92','Sao Paulo','(11) 555-9857','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('C/ Moralzarzal, 86','Madrid','(91) 555 94 44','(91) 555 55 93',16);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('184, chaussee de Tournai','Lille','20.16.10.16','20.16.10.17',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Akergatan 24','Bracke','0695-34 67 21','',17);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Berliner Platz 43','Munchen','089-0877310','089-0877451',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('54, rue Royale','Nantes','40.32.21.21','40.32.21.20',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Via Monte Bianco 34','Torino','011-4988260','011-4988261',11);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Jardim das rosas n. 32','Lisboa','(1) 354-2534','(1) 354-2535',15);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rambla de Cataluna, 23','Barcelona','(93) 203 4560','(93) 203 4561',16);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('C/ Romero, 33','Sevilla','(95) 555 82 82','',16);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Av. Brasil, 442','Campinas','(11) 555-9482','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2732 Baker Blvd.','Eugene','(503) 555-7555','',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('5? Ave. Los Palos Grandes','Caracas','(2) 283-2951','(2) 283-3397',21);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rua do Paco, 67','Rio de Janeiro','(21) 555-0091','(21) 555-8765',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Carrera 22 con Ave. Carlos Soublette #8-35','San Cristobal','(5) 555-1340','(5) 555-1948',21);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('City Center Plaza 516 Main St.','Elgin','(503) 555-6874','(503) 555-2376',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('8 Johnstown Road','Cork','2967 542','2967 3333',10);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Garden House Crowther Way','Cowes','(198) 555-8888','',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Maubelstr. 90','Brandenburg','0555-09876','',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('67, avenue de l Europe','Versailles','30.59.84.10','30.59.85.11',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('1 rue Alsace-Lorraine','Toulouse','61.77.61.10','61.77.61.11',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('1900 Oak St.','Vancouver','(604) 555-3392','(604) 555-7293',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('12 Orchestra Terrace','Walla Walla','(509) 555-7969','(509) 555-6221',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Magazinweg 7','Frankfurt a.M.','069-0245984','069-0245874',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('87 Polk St. Suite 5','San Francisco','(415) 555-5938','',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Carrera 52 con Ave. Bolivar #65-98 Llano Largo','Barquisimeto','(9) 331-6954','(9) 331-7256',21);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Ave. 5 de Mayo Porlamar','I. de Margarita','(8) 34-56-12','(8) 34-93-93',21);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('89 Chiaroscuro Rd.','Portland','(503) 555-9573','(503) 555-9646',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Via Ludovico il Moro 22','Bergamo','035-640230','035-640231',11);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rue Joseph-Bens 532','Bruxelles','(02) 201 24 67','(02) 201 24 68',3);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('43 rue St. Laurent','Montreal','(514) 555-8054','(514) 555-8055',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Heerstr. 22','Leipzig','0342-023176','',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('South House 300 Queensbridge','London','(171) 555-7733','(171) 555-2530',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Ing. Gustavo Moncada 8585 Piso 20-A','Buenos Aires','(1) 135-5333','(1) 135-5535',1);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2743 Bering St.','Anchorage','(907) 555-7584','(907) 555-2880',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Mehrheimerstr. 369','Koln','0221-0644327','0221-0765721',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('265, boulevard Charonne','Paris','(1) 42.34.22.66','(1) 42.34.22.77',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Calle Dr. Jorge Cash 321','Mexico D.F.','(5) 552-3745','(5) 545-3745',12);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Geislweg 14','Salzburg','6562-9722','6562-9723',2);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Estrada da saude n. 58','Lisboa','(1) 356-5634','',15);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rua da Panificadora, 12','Rio de Janeiro','(21) 555-4252','(21) 555-4545',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Alameda dos Canarios, 891','Sao Paulo','(11) 555-1189','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Taucherstra?e 10','Cunewalde','0372-035188','',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Av. del Libertador 900','Buenos Aires','(1) 123-5555','(1) 123-5556',1);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2817 Milton Dr.','Albuquerque','(505) 555-5939','(505) 555-3620',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Strada Provinciale 124','Reggio Emilia','0522-556721','0522-556722',11);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Av. Copacabana, 267','Rio de Janeiro','(21) 555-3412','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Grenzacherweg 237','Geneve','0897-034214','',18);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Gran Via, 1','Madrid','(91) 745 6200','(91) 745 6210',16);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Erling Skakkes gate 78','Stavern','07-98 92 35','07-98 92 47',13);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('187 Suffolk Ln.','Boise','(208) 555-8097','',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('90 Wadhurst Rd.','London','(171) 555-1717','(171) 555-5646',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Vinb?ltet 34','Kobenhavn','31 12 34 56','31 13 35 57',6);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('25, rue Lauriston','Paris','(1) 47.55.60.10','(1) 47.55.60.20',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('P.O. Box 555','Lander','(307) 555-4680','(307) 555-6525',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Boulevard Tirou, 255','Charleroi','(071) 23 67 22 20','(071) 23 67 22 21',3);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('89 Jefferson Way Suite 2','Portland','(503) 555-3612','',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('55 Grizzly Peak Rd.','Butte','(406) 555-5834','(406) 555-8083',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Luisenstr. 48','Munster','0251-031259','0251-035695',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Avda. Azteca 123','Mexico D.F.','(5) 555-2933','',12);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Av. Ines de Castro, 414','Sao Paulo','(11) 555-2167','(11) 555-2168',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('722 DaVinci Blvd.','Kirkland','(206) 555-8257','(206) 555-2174',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Smagsloget 45','Arhus','86 21 32 43','86 22 33 44',6);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2, rue du Commerce','Lyon','78.32.54.86','78.32.54.87',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('59 rue de l Abbaye','Reims','26.47.15.10','26.47.15.11',8);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Adenauerallee 900','Stuttgart','0711-020361','0711-035428',9);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Torikatu 38','Oulu','981-443655','981-443655',7);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Rua do Mercado, 12','Resende','(14) 555-8122','',4);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('305 - 14th Ave. S. Suite 3B','Seattle','(206) 555-4112','(206) 555-4115',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Keskuskatu 45','Helsinki','90-224 8858','90-224 8858',7);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('ul. Filtrowa 68','Warszawa','(26) 642-7012','(26) 642-7012',14);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('4287 Maple Hill St.','Dallas','(513) 428-2999','(513) 428-2930',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('98 Michaels Lane','Irvine','(514) 229-9228','(514) 229-9229',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('287 Oak Drive','Houston','(171) 555-7788','(171) 555-7789',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2767 LBJ Hwy Suite 1','Dallas','(888) 288-2229','(888) 288-2230',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('5998 Hoffner Blvd Suite 1','Inglewood','(488) 288-9992','(488) 288-9945',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('4726 Harper Hill St. Apt 1','Los Angeles','(288) 288-9288','(288) 288-9289',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('247 5th Ave Apt 487','New York','(877) 828-9229','(877) 828-9240',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('4287 Indiane Rd','Thomasville','(824) 882-2992','(824) 882-2993',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('24 Tsawassen Blvd.','Ontario','(604) 842-3998','(604) 842-3999',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2587 Trans Canada Hwy','Montreal','(276) 278-2827','(276) 278-2829',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('892 Rocket Richard Way','Toronto','(827) 843-3872','(827) 843-3873',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('2767 Wayne Gretzy Hwy Apt 1','Edmonton','(726) 288-2887','(726) 288-2888',5);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Hauptstr. 29','Bern','(   ) 452-0765','973-7252',18);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('38427 Smith St.','Los Angeles','(213) 284-9938','(213) 284-9939',20);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Berkeley Gardens 22  Brewery','London','(171) 554-5228','(171) 554-5229',19);
INSERT INTO physical_address (street, city, phone, fax, countryID) VALUES('Walserweg 20','Aachen','(423) 241-0312','021-0428',9);

/*Insert table persons*/
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Maria','Anders',cast('1946-10-23 15:39:37.273' as datetime) , 'MariaA@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Ana','Trujillo',cast('1982-04-17 15:39:37.273' as datetime) , 'AnaT@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Antonio','Moreno',cast('1977-05-13 15:39:37.273' as datetime) , 'AntonioM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Thomas','Hardy',cast('1971-06-14 15:39:37.273' as datetime) , 'ThomasH@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Christina','Berglund',cast('1970-06-19 15:39:37.273' as datetime) , 'ChristinaB@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Hanna','Moos',cast('1972-06-08 15:39:37.273' as datetime) , 'HannaM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Frederique','Citeaux',cast('1933-01-04 15:39:37.273' as datetime) , 'FrederiqueC@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Martin','Sommer',cast('1974-05-29 15:39:37.273' as datetime) , 'MartinS@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Laurence','Lebihan',cast('1942-11-13 15:39:37.273' as datetime) , 'LaurenceL@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Elizabeth','Lincoln',cast('1963-07-26 15:39:37.277' as datetime) , 'ElizabethL@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Victoria','Ashworth',cast('1969-06-24 15:39:37.277' as datetime) , 'VictoriaA@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Patricio','Simpson',cast('1940-11-23 15:39:37.277' as datetime) , 'PatricioS@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Francisco','Chang',cast('1947-10-18 15:39:37.277' as datetime) , 'FranciscoC@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Yang','Wang',cast('1957-08-26 15:39:37.277' as datetime) , 'YangW@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Pedro','Afonso',cast('1933-12-30 15:39:37.277' as datetime) , 'PedroA@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Elizabeth','Brown',cast('1938-12-04 15:39:37.277' as datetime) , 'ElizabethB@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Sven','Ottlieb',cast('1936-12-14 15:39:37.277' as datetime) , 'SvenO@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Janine','Labrune',cast('1935-12-20 15:39:37.277' as datetime) , 'JanineL@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Ann','Devon',cast('1955-09-06 15:39:37.277' as datetime) , 'AnnD@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Roland','Mendel',cast('1950-10-02 15:39:37.277' as datetime) , 'RolandM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Aria','Cruz',cast('1939-11-29 15:39:37.277' as datetime) , 'AriaC@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Diego','Roel',cast('1937-12-09 15:39:37.277' as datetime) , 'DiegoR@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Martine','Rance',cast('1939-11-29 15:39:37.280' as datetime) , 'MartineR@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Maria','Larsson',cast('1983-04-12 15:39:37.280' as datetime) , 'MariaL@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Peter','Franken',cast('1960-08-10 15:39:37.280' as datetime) , 'PeterF@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Carine','Schmitt',cast('1941-11-18 15:39:37.280' as datetime) , 'CarineS@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Paolo','Accorti',cast('1956-08-31 15:39:37.280' as datetime) , 'PaoloA@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Lino','Rodriguez',cast('1965-07-15 15:39:37.280' as datetime) , 'LinoR@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Eduardo','Saavedra',cast('1944-11-02 15:39:37.280' as datetime) , 'EduardoS@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jose','Pedro Freyre',cast('1986-03-27 15:39:37.280' as datetime) , 'JoseP@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Andre','Fonseca',cast('1974-05-29 15:39:37.280' as datetime) , 'AndreF@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Howard','Snyder',cast('1975-05-24 15:39:37.280' as datetime) , 'HowardS@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Manuel','Pereira',cast('1960-08-10 15:39:37.280' as datetime) , 'ManuelP@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Mario','Pontes',cast('1953-09-16 15:39:37.280' as datetime) , 'MarioP@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Carlos','Hernandez',cast('1938-12-04 15:39:37.280' as datetime) , 'CarlosH@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Yoshi','Latimer',cast('1983-04-12 15:39:37.283' as datetime) , 'YoshiL@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Patricia','McKenna',cast('1948-10-12 15:39:37.283' as datetime) , 'PatriciaM@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Helen','Bennett',cast('1986-03-27 15:39:37.283' as datetime) , 'HelenB@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Philip','Cramer',cast('1953-09-16 15:39:37.283' as datetime) , 'PhilipC@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Daniel','Tonini',cast('1951-09-27 15:39:37.283' as datetime) , 'DanielT@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Annette','Roulet',cast('1973-06-03 15:39:37.283' as datetime) , 'AnnetteR@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Yoshi','Tannamuri',cast('1951-09-27 15:39:37.283' as datetime) , 'YoshiT@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('John','Steel',cast('1975-05-24 15:39:37.283' as datetime) , 'JohnS@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Renate','Messner',cast('1974-05-29 15:39:37.283' as datetime) , 'RenateM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jaime','Yorres',cast('1952-09-21 15:39:37.283' as datetime) , 'JaimeY@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Carlos','Gonzalez',cast('1955-09-06 15:39:37.283' as datetime) , 'CarlosG@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Felipe','Izquierdo',cast('1984-04-06 15:39:37.283' as datetime) , 'FelipeI@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Fran','Wilson',cast('1954-09-11 15:39:37.283' as datetime) , 'FranW@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Giovanni','Rovelli',cast('1979-05-03 15:39:37.287' as datetime) , 'GiovanniR@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Catherine','Dewey',cast('1948-10-12 15:39:37.287' as datetime) , 'CatherineD@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jean','Fresniere',cast('1940-11-23 15:39:37.287' as datetime) , 'JeanF@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Alexander','Feuer',cast('1950-10-02 15:39:37.287' as datetime) , 'AlexanderF@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Simon','Crowther',cast('1933-01-04 15:39:37.287' as datetime) , 'SimonC@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Yvonne','Moncada',cast('1955-09-06 15:39:37.287' as datetime) , 'YvonneM@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Rene','Phillips',cast('1963-07-26 15:39:37.287' as datetime) , 'ReneP@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Henriette','Pfalzheim',cast('1945-10-28 15:39:37.287' as datetime) , 'HenrietteP@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Marie','Bertrand',cast('1957-08-26 15:39:37.287' as datetime) , 'MarieB@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Guillermo','Fernandez',cast('1943-11-08 15:39:37.290' as datetime) , 'GuillermoF@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Georg','Pipps',cast('1949-10-07 15:39:37.290' as datetime) , 'GeorgP@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Isabel','de Castro',cast('1974-05-29 15:39:37.290' as datetime) , 'Isabeld@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Bernardo','Batista',cast('1944-11-02 15:39:37.290' as datetime) , 'BernardoB@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Lucia','Carvalho',cast('1984-04-06 15:39:37.290' as datetime) , 'LuciaC@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Horst','Kloss',cast('1961-08-05 15:39:37.290' as datetime) , 'HorstK@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Sergio','Gutierrez',cast('1968-06-29 15:39:37.290' as datetime) , 'SergioG@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Paula','Wilson',cast('1972-06-08 15:39:37.290' as datetime) , 'PaulaW@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Maurizio','Moroni',cast('1937-12-09 15:39:37.290' as datetime) , 'MaurizioM@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Janete','Limeira',cast('1952-09-21 15:39:37.290' as datetime) , 'JaneteL@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Michael','Holz',cast('1960-08-10 15:39:37.290' as datetime) , 'MichaelH@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Alejandra','Camino',cast('1946-10-23 15:39:37.290' as datetime) , 'AlejandraC@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jonas','Bergulfsen',cast('1954-09-11 15:39:37.290' as datetime) , 'JonasB@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jose','Pavarotti',cast('1946-10-23 15:39:37.290' as datetime) , 'JoseP@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Hari','Kumar',cast('1958-08-21 15:39:37.290' as datetime) , 'HariK@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jytte','Petersen',cast('1979-05-03 15:39:37.290' as datetime) , 'JytteP@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Dominique','Perrier',cast('1978-05-08 15:39:37.290' as datetime) , 'DominiqueP@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Art','Braunschweiger',cast('1947-10-18 15:39:37.290' as datetime) , 'ArtB@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Pascale','Cartrain',cast('1976-05-18 15:39:37.293' as datetime) , 'PascaleC@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Liz','Nixon',cast('1981-04-22 15:39:37.293' as datetime) , 'LizN@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Liu','Wong',cast('1971-06-14 15:39:37.293' as datetime) , 'LiuW@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Karin','Josephs',cast('1949-10-07 15:39:37.293' as datetime) , 'KarinJ@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Miguel','Angel Paolino',cast('1980-04-27 15:39:37.293' as datetime) , 'MiguelA@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Anabela','Domingues',cast('1937-12-09 15:39:37.293' as datetime) , 'AnabelaD@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Helvetius','Nagy',cast('1975-05-24 15:39:37.293' as datetime) , 'HelvetiusN@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Palle','Ibsen',cast('1943-11-08 15:39:37.293' as datetime) , 'PalleI@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Mary','Saveley',cast('1964-07-20 15:39:37.293' as datetime) , 'MaryS@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Paul','Henriot',cast('1936-12-14 15:39:37.293' as datetime) , 'PaulH@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Rita','Muller',cast('1948-10-12 15:39:37.293' as datetime) , 'RitaM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Pirkko','Koskitalo',cast('1944-11-02 15:39:37.297' as datetime) , 'PirkkoK@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Paula','Parente',cast('1983-04-12 15:39:37.297' as datetime) , 'PaulaP@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Karl','Jablonski',cast('1975-05-24 15:39:37.297' as datetime) , 'KarlJ@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Matti','Karttunen',cast('1935-12-20 15:39:37.297' as datetime) , 'MattiK@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Zbyszek','Piestrzeniewicz',cast('1985-04-01 15:39:37.297' as datetime) , 'ZbyszekP@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Brad','Barnes',cast('1946-10-23 15:39:37.297' as datetime) , 'BradB@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jerry','Campbell',cast('1965-07-15 15:39:37.297' as datetime) , 'JerryC@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Carl','Lucas',cast('1948-10-12 15:39:37.297' as datetime) , 'CarlL@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Peter','Dolan',cast('1943-11-08 15:39:37.297' as datetime) , 'PeterD@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Ryan','Fischer',cast('1958-08-21 15:39:37.297' as datetime) , 'RyanF@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Richard','Fisher',cast('1971-06-14 15:39:37.297' as datetime) , 'RichardF@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Tom','Hamlett',cast('1965-07-15 15:39:37.297' as datetime) , 'TomH@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Mark','Hamilton',cast('1947-10-18 15:39:37.300' as datetime) , 'MarkH@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Steve','Lee',cast('1982-04-17 15:39:37.300' as datetime) , 'SteveL@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jimmy','Lewis',cast('1973-06-03 15:39:37.300' as datetime) , 'JimmyL@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Jeffrey','McClain',cast('1963-07-26 15:39:37.300' as datetime) , 'JeffreyM@vegassoftware.com',2    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Andrew','Miller',cast('1946-10-23 15:39:37.300' as datetime) , 'AndrewM@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Dave','Murrel',cast('1983-04-12 15:39:37.300' as datetime) , 'DaveM@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Bert','Parkins',cast('1961-08-05 15:39:37.300' as datetime) , 'BertP@vegassoftware.com',3    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Mike','Roller',cast('1969-06-24 15:39:37.300' as datetime) , 'MikeR@vegassoftware.com',1    );
INSERT INTO person(firstname,lastname, birthdate, email ,civilstateID) VALUES('Ray','Shipman',cast('1935-12-20 15:39:37.300' as datetime) , 'RayS@vegassoftware.com',3    );

/*Insert table address_person*/
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(1, 1, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(2, 2, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(3, 3, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(4, 4, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(5, 5, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(6, 6, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(7, 7, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(8, 8, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(9, 9, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(10, 10, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(11, 11, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(12, 12, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(13, 13, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(14, 14, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(15, 15, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(16, 16, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(17, 17, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(18, 18, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(19, 19, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(20, 20, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(21, 21, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(22, 22, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(23, 23, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(24, 24, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(25, 25, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(26, 26, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(27, 27, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(28, 28, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(29, 29, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(30, 30, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(31, 31, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(32, 32, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(33, 33, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(34, 34, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(35, 35, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(36, 36, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(37, 37, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(38, 38, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(39, 39, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(40, 40, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(41, 41, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(42, 42, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(43, 43, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(44, 44, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(45, 45, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(46, 46, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(47, 47, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(48, 48, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(49, 49, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(50, 50, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(51, 51, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(52, 52, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(53, 53, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(54, 54, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(55, 55, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(56, 56, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(57, 57, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(58, 58, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(59, 59, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(60, 60, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(61, 61, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(62, 62, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(63, 63, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(64, 64, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(65, 65, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(66, 66, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(67, 67, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(68, 68, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(69, 69, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(70, 70, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(71, 71, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(72, 72, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(73, 73, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(74, 74, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(75, 75, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(76, 76, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(77, 77, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(78, 78, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(79, 79, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(80, 80, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(81, 81, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(82, 82, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(83, 83, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(84, 84, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(85, 85, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(86, 86, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(87, 87, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(88, 88, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(89, 89, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(90, 90, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(91, 91, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(92, 92, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(93, 93, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(94, 94, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(95, 95, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(96, 96, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(97, 97, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(98, 98, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(99, 99, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(100, 100, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(101, 101, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(102, 102, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(103, 103, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(104, 104, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(105, 105, 1);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(106, 106, 2);
INSERT INTO address_person(personID,addressID, addresstypeID) VALUES(107, 107, 2);

                         

DROP PROCEDURE if exists NewPerson;
/*Create SP to insert a new person*/
CREATE PROCEDURE NewPerson(v_FIRSTNAME VARCHAR(50),
v_LASTNAME VARCHAR(50),
v_BIRTHDATE DATETIME ,
v_CIVILSTATE TINYINT UNSIGNED ,
INOUT v_NEWID INT)
BEGIN
   IF v_CIVILSTATE is null then
      set v_CIVILSTATE = 0;
   END IF;
INSERT INTO person(firstname,lastname, birthdate,civilstateID)
  VALUES(v_FIRSTNAME, v_LASTNAME, v_BIRTHDATE ,v_CIVILSTATE);
  
   SET v_NEWID = LAST_INSERT_ID();
END;

       
DROP PROCEDURE if exists PersonsByCountry;
/*Create SP to insert a new person*/
CREATE PROCEDURE PersonsByCountry(v_COUNTRYID INT,
v_ADDRESTYPE TINYINT UNSIGNED)
BEGIN
   SELECT p.*, pa.*, `at`.type_descrip, cs.state_descrip, c.country_name
   FROM person p
   INNER JOIN address_person ap ON p.personID = ap.personID
   INNER JOIN physical_address pa ON ap.addressID = pa.addressID
   INNER JOIN address_type `at` ON ap.addresstypeID = `at`.addresstypeID
   INNER JOIN civil_state cs ON p.civilstateID = cs.civilstateID
   INNER JOIN country c ON pa.countryID = c.countryID
   WHERE pa.countryID = v_COUNTRYID
   AND ap.addresstypeID = v_ADDRESTYPE;
END;

DROP PROCEDURE if exists UpdatePhoto;
/*Update with image parameter*/
CREATE PROCEDURE UpdatePhoto(v_PERSONID INT,
v_PHOTO LONGBLOB)
BEGIN
   UPDATE person SET
   photo = v_PHOTO
   WHERE personID = v_PERSONID;
END;



