#region license

/*
EasyBuildSQL - is a C# library oriented to help to developers to build sql sentence in differents database engine. 
EasyBuildSQL is developed to .NET Framework.
 
Copyright (C) 2010 - Alejandro Genovesi
http://sourceforge.net/projects/easybuildsql/ 
Contributor : Arturo Martinez

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 
*/

#endregion

using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.SqlClient;
using System.Text.RegularExpressions;
using System.Data.Common;
using System.IO;

namespace EasyBuildSQL
{
  public abstract class DataModify : SQLSentence
  {
    public event EventHandler Finished;
    protected virtual void OnFinished(EventArgs e)
    {
      EventHandler handler = Finished;
      if (handler != null)
      {
        handler(this, e);
      }
    }

    protected string fTable;
    protected bool fInitiated;
    public string IdentityValueEnabled
    { get; set; }

    public bool UseIdentityEnabled
    { get; set; }

    public virtual void AddValue(string Field, object Value)
    {
      string sValue = string.Empty;

      if (Value.GetType().IsEnum)
        sValue = Convert.ToInt64(Value).ToString();
      else
        switch (Value.GetType().Name.ToLowerInvariant())
        {
          case "int":
          case "int16":
          case "int32":
          case "int64":
          case "short":
          case "long":
          case "ulong":
          case "ushort":
          case "float":
          case "single":
          case "double":
          case "byte":
            sValue = Value.ToString();
            break;

          case "datetime":

            DateTime dValue = (DateTime)Value;

            switch (fDBType)
            {
              case DataBaseType.MSSQL:
                    sValue = MSSQL.DateTimeToStr(dValue);
                break;

              case DataBaseType.MySQL:
                sValue = MySQL.DateTimeToStr(dValue);
                break;

            }


            break;

          case "bool":
          case "boolean":

            bool bValue = (bool)Value;

            switch (fDBType)
            {
              case DataBaseType.MSSQL:
                sValue = MSSQL.BoolToStr(bValue);
                break;

              case DataBaseType.MySQL:
                sValue = MySQL.BoolToStr(bValue);
                break;

            }


            break;

          case "string":
            AddField(Field, DbType.AnsiString, Value);
            return;

          case "char":
            AddField(Field, DbType.AnsiStringFixedLength, Value);
            return;

          default:
            throw new InvalidCastException("AddValue: no se pudo determinar el tipo del valor entregado como parmetro");
        }

      Add(Field, sValue, true);
    }

    protected virtual void Add(string Field, string Parameter, bool isLiteral)
    {
      if (!fInitiated)
        Initiate();
    }

    protected virtual void Add(string Field, string Parameter)
    {
      Add(Field, Parameter, false);
    }

    public virtual void Initiate()
    {
      fInitiated = true;
    }

    public virtual void Finish()
    {
      if (!fInitiated)
        throw new NotSupportedException("DataModify.Finish: sentence with bad initiation ");

      fInitiated = false;

      if (Finished != null)
        Finished(this, new EventArgs());
    }

    public DataModify(DbCommand Command, DataBaseType DBType, string Table)
      : base(Command, DBType)
    {
      fTable = Table;
    }

    public void AddField(string Name, string Parameter, DbType Type, object Value, int Large)
    {
      Add(Name, Parameter);

      CreateParameter(Parameter, Type, Value, Large);
    }

    public void AddField(string Name, DbType Type, object Value, int Large)
    {
      AddField(Name, Name, Type, Value, Large);
    }

    public void AddField(string Name, DbType Type, object Value)
    {
      AddField(Name, Type, Value, 0);
    }

    public void AddField(string Name, string Parameter, DbType Type, object Value)
    {
      AddField(Name, Parameter, Type, Value, 0);
    }

    public void AddBLOB(string Field, string Parameter, string FileName)
    {
      if (File.Exists(FileName))
      {
        DbParameter pBlob = CreateParameter(Parameter, DbType.Binary, null);

        Add(Field, Parameter);

        if (FileName.Length != 0)
        {
          byte[] buffer = BlobSQL.LoadFromFile(FileName);

          if (buffer.Length > 0)
          {
            pBlob.Value = buffer;
          }
        }
      }
      else
        AddNULL(Field);
    }

    public void AddBLOB(string Field, string FileName)
    {
        AddBLOB(Field, Field, FileName);
    }

    public void AddBLOB(string Field, string Parameter, Stream Stream)
    {
      DbParameter pBlob = CreateParameter(Parameter, DbType.Binary, null);

      Add(Field, Parameter);

      if (Stream.Length != 0)
      {
        byte[] buffer = BlobSQL.LoadFromStream(Stream);

        if (buffer.Length > 0)
        {
          pBlob.Value = buffer;
        }
      }
    }

    public void AddBLOB(string Field, Stream Stream)
    {
        AddBLOB(Field, Field, Stream);
    }


    public void AddTEXT(string Field, string Parameter, string FileName)
    {
        if (File.Exists(FileName))
      {
        DbParameter pTEXT = CreateParameter(Parameter, DbType.String , null);//verificar

        Add(Field, Parameter);

        if (FileName.Length != 0)
            pTEXT.Value = BlobSQL.LoadTextFromFile(FileName);
      }
      else
            AddNULL(Field);
    }

    public void AddTEXT(string Field, string FileName)
    {
        AddTEXT(Field, Field, FileName);
    }

    public void AddNULL(string Field)
    {
      string strNULL = null;

      switch (fDBType)
      {
        case DataBaseType.MSSQL:
          strNULL = MSSQL.NULL;
          break;

        case DataBaseType.MySQL:
          strNULL = MySQL.NULL;
          break;

      }

      Add(Field, strNULL, true);
    }

    public void AddGETDATE(string Field)
    {
      string strGETDATE = null;

      switch (fDBType)
      {
        case DataBaseType.MSSQL:
          strGETDATE = MSSQL.GETDATE;
          break;

        case DataBaseType.MySQL:
          strGETDATE = MySQL.GETDATE;
          break;

      }

      Add(Field, strGETDATE, true);
    }

    public void AddIdentity(string Field)
    {
      switch (fDBType)
      {
        case DataBaseType.MSSQL:
          if (UseIdentityEnabled)
              Add(Field, MSSQL.IDENTITY_AVAILABLE, true);
          else
              Add(Field, MSSQL.IDENTITY, true);

          break;

        case DataBaseType.MySQL:
          if (UseIdentityEnabled)
              Add(Field, MySQL.IDENTITY_AVAILABLE, true);
          else
              Add(Field, MySQL.IDENTITY, true);

          break;

        default:
          Add(Field, IdentityValueEnabled, true);
          break;
      }
    }
  }


  public class DataINSERT : DataModify
  {
    private StringBuilder fFields;
    private StringBuilder fValues;

    public DataINSERT(DbCommand Command, DataBaseType DBType, string Table)
      : base(Command, DBType, Table)
    {
    }

    private bool fReturnIDENTITY;
    public bool ReturnIDENTITY
    {
      get
      {
        return fReturnIDENTITY;
      }
      set
      {
        fReturnIDENTITY = value;
      }
    }

    protected override void Add(string Field, string Parameter, bool isLiteral)
    {
      base.Add(Field, Parameter, isLiteral);

      if (fFields.Length > 1)
      {
        fFields.Append(",");
        fValues.Append(",");
      }

      fFields.Append(Field);

      if (isLiteral)
        fValues.Append(Parameter);
      else
      {
        if (fDBType == DataBaseType.MySQL)
          fValues.Append(String.Format("?{0}", Parameter));
        else
          fValues.Append(String.Format("@{0}", Parameter));
      }
    }


    public override void Initiate()
    {
      base.Initiate();

      fFields = new StringBuilder();
      fValues = new StringBuilder();

      fFields.Append("(");
      fValues.Append(" VALUES (");
    }

    public override void Finish()
    {
      if ((fFields.Length <= 1) && (!fInitiated))
        Initiate();

      if (fFields.Length > 1)
      {

        AddText(String.Format("INSERT INTO {0}", fTable));
        fFields.Append(")");
        fValues.Append(");");
        AddText(fFields.ToString());
        AddText(fValues.ToString());

        if (fReturnIDENTITY)
          switch (fDBType)
          {
            case DataBaseType.MSSQL:
              if (UseIdentityEnabled)
                AddText(MSSQL.ReturnIDENTITYAvailable);
              else
                AddText(MSSQL.ReturnIDENTITY);

              break;

            case DataBaseType.MySQL:
              if (UseIdentityEnabled)
                AddText(MySQL.ReturnIDENTITYAvailable);
              else
                AddText(MySQL.ReturnIDENTITY);

              break;

          }
      }

      base.Finish();
    }
  }

  public class DataUPDATE : DataModify
  {
    private StringBuilder fFields = null;
    private StringBuilder fCondition = null;

    public DataUPDATE(DbCommand Command, DataBaseType DBType, string Table)
      : base(Command, DBType, Table)
    {
    }

    public string Condition
    {
      get
      {
        if (fCondition == null)
          return "";
        else
          return fCondition.ToString();
      }
      set
      {
        fCondition = new StringBuilder(value);
      }
    }

    public void AddCondition(string Clause)
    {
      if (fCondition == null)
        fCondition = new StringBuilder(Clause);
      else
        fCondition.AppendLine(Clause);
    }

    protected override void Add(string Field, string Parameter, bool isLiteral)
    {
      base.Add(Field, Parameter, isLiteral);

      if (fFields.Length > 0)
        fFields.Append(",");

      if (isLiteral)
        fFields.Append(String.Format("{0} = {1}", Field, Parameter));
      else
      {
        if (fDBType == DataBaseType.MySQL)
          fFields.Append(String.Format("{0} = ?{1}", Field, Parameter));
        else
          fFields.Append(String.Format("{0} = @{1}", Field, Parameter));
      }
    }

    public override void Initiate()
    {
      base.Initiate();

      fFields = new StringBuilder();
    }

    public override void Finish()
    {
      if ((fFields.Length == 0) && (!fInitiated))
        Initiate();

      if (fFields.Length > 0)
      {
        AddText(String.Format("UPDATE {0} SET", fTable));

        if (fCondition.Length == 0)
          throw
            new NotSupportedException("DataUPDATE.Finalizar: La condicin de la sentencia de actualizacin SQL no puede estar vaca");

        AddText(fFields.ToString());

        AddText(String.Format("WHERE {0};", fCondition));
      } 

      base.Finish();
    }
  }
}
