#region license

/*
EasyBuildSQL - is a C# library oriented to help to developers to build sql sentence in differents database engine. 
EasyBuildSQL is developed to .NET Framework.
 
Copyright (C) 2010 - Alejandro Genovesi
http://sourceforge.net/projects/easybuildsql/ 
Contributor : Arturo Martinez

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 
*/

#endregion

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;
using System.ComponentModel;
using System.Data.SqlClient;
using System.Data;
using System.Data.Common;
using MySql.Data.MySqlClient;

namespace EasyBuildSQL
{
    public class ebBATCH : ebSQL
    {
        private StringBuilder fSQLBatch;
        private ebSQLSentence fScript;

        private string fCurrentTableINSERT = null;
        private string fIDENTITY_VALUE = null;
        private string fIdentityPhrase = null;

        public ebBATCH(string UserName, string Password, string DBName, string Server, DataBaseType DBType)
            : base(UserName, Password, DBName, Server, DBType)
        {
            fScript = new ebSQLSentence(fCommand, DBType);
            fSQLBatch = new StringBuilder();

            Initialize();
        }

        public ebBATCH(ConnectionCredentials Credentials)
            : base(Credentials)
        {
            fScript = new ebSQLSentence(fCommand, Credentials.ObtainDBType());
            fSQLBatch = new StringBuilder();

            Initialize();
        }
        
        bool fSentenceIsOpen;
        SQLSentence OpenedSQLSentence;

        private bool fReturnIDENTITY;
        public bool ReturnIDENTITY
        {
            get
            {
                return fReturnIDENTITY;
            }
            set
            {
                fReturnIDENTITY = value;
            }
        }

        private int fIdentity;
        public int Identity
        {
            get
            {
                return fIdentity;
            }
        }

        protected void CheckOpenedSentence()
        {
            if (fSentenceIsOpen)
                throw new NotSupportedException("ebBATCH: Hay una sentencia SQL que espera ser finalizada");

            if (OpenedSQLSentence != null)
            {
                OpenedSQLSentence = null;
            }
        }

        protected void RegisterOpenedSentence(SQLSentence Sentence)
        {
            fSentenceIsOpen = true;
            OpenedSQLSentence = Sentence;

            fSQLBatch.AppendLine(fScript.SentenceSQL);
            fScript.Clear();
        }

        protected override void Initialize()
        {
            base.Initialize();

            switch (fDBType)
            {
                case DataBaseType.MSSQL:
                    fSQLBatch.AppendLine(MSSQL.BEGIN_TRANSACTION);
                    break;

                case DataBaseType.MySQL:
                    fSQLBatch.AppendLine(MySQL.BEGIN_TRANSACTION);
                    break;

            }
        }

        public DataINSERT Insert(string Table)
        {
            CheckOpenedSentence();

            DataINSERT Insert = new DataINSERT(fCommand, fDBType, Table);

            Insert.Finished += new EventHandler(SentenceFinished);

            Insert.UseIdentityEnabled = fIdentityAvailable;

            fCurrentTableINSERT = Table;

            RegisterOpenedSentence(Insert);

            return Insert;
        }

        public DataUPDATE Update(string Table)
        {
            CheckOpenedSentence();

            DataUPDATE Update = new DataUPDATE(fCommand, fDBType, Table);

            Update.Finished += new EventHandler(SentenceFinished);

            RegisterOpenedSentence(Update);

            return Update;
        }

        private void SentenceFinished(object sender, EventArgs e)
        {
            fSentenceIsOpen = false;

            fSQLBatch.AppendLine(OpenedSQLSentence.SentenceSQL);
        }

        public void AddSQL(string SQL)
        {
            CheckOpenedSentence();

            fScript.Add(SQL);
        }

        public DbParameter AddParameter(string Name, DbType Type, int Large)
        {
            CheckOpenedSentence();

            return fScript.AddParameter(Name, Type, null, Large);
        }

        public DbParameter AddParameter(string Name, DbType Type)
        {
            return AddParameter(Name, Type, 0);
        }

        protected bool fIdentityAvailable;

        public void GetIdentity()
        {
            if (fReturnIDENTITY && (fCurrentTableINSERT != null))
            {
                switch (fDBType)
                {
                    case DataBaseType.MSSQL:
                        fSQLBatch.AppendLine(MSSQL.DeclareIDENTITY);
                        fSQLBatch.AppendLine(MSSQL.GetIDENTITY);
                        fIdentityPhrase = MSSQL.IDENTITY_AVAILABLE;
                        break;

                    case DataBaseType.MySQL:
                        fSQLBatch.AppendLine(MySQL.GetIDENTITY);
                        fIdentityPhrase = MySQL.IDENTITY_AVAILABLE;
                        break;

                }

                fIdentityAvailable = true;
            }
            else
                throw new NotSupportedException("ebBATCH.GetIdentity: No se ha definido el retorno de IDENTITY");
        }

        public override bool Execute()
        {
            try
            {
                Finish();

                if (fReturnIDENTITY)
                    fIdentity = Convert.ToInt32(fCommand.ExecuteScalar());
                else
                    fCommand.ExecuteNonQuery();

                fConnection.Close();

                return true;
            }
            catch (Exception e)
            {
                fConnection.Close();
                fErrorSQL = e.Message;

                return false;
            }
        }

        public DbDataReader OpenDataReader()
        {
            try
            {
                Finish();

                DbDataReader Result;

                Result = fCommand.ExecuteReader(CommandBehavior.CloseConnection);

                if (fReturnIDENTITY)
                {
                    Result.Read();
                    fIdentity = (Int32)Result[0];
                }

                return Result;
            }
            catch (Exception e)
            {
                fConnection.Close();
                fErrorSQL = e.Message;

                return null;
            }
        }

        public DataSet OpenDataSet()
        {

            try
            {
                DbDataAdapter Adapter;
                Finish();

                DataSet Result = new DataSet();


                switch (fConnection.DataBase)
                {
                    case DataBaseType.MSSQL:
                        {
                            Adapter = new SqlDataAdapter();
                            Adapter.Fill(Result);
                        }
                        break;

                    case DataBaseType.MySQL:
                        {
                            Adapter = new MySqlDataAdapter();
                            Adapter.Fill(Result);
                        }
                        break;

                }

                if (fReturnIDENTITY)
                {
                    DataRow Record = Result.Tables[0].Rows[0];

                    fIdentity = ebField.AsInteger(Record["NUEVO"]);
                }

                fConnection.Close();

                return Result;
            }
            catch (Exception e)
            {
                fConnection.Close();
                fErrorSQL = e.Message;

                return null;
            }
        }

        private void Finish()
        {
            switch (fDBType)
            {
                case DataBaseType.MSSQL:
                    if (fReturnIDENTITY)
                    {
                        fScript.Add (MSSQL.ReturnIDENTITYAvailable);

                        fIdentityAvailable = false;
                    } // if

                    fScript.Add(MSSQL.COMMIT);
                    break;

                case DataBaseType.MySQL:
                    if (fReturnIDENTITY)
                    {
                        fScript.Add(MySQL.ReturnIDENTITYAvailable);

                        fIdentityAvailable = false;
                    } // if

                    fScript.Add(MySQL.COMMIT);
                    break;

            }

            fSQLBatch.AppendLine(fScript.SentenceSQL);

            fCommand.CommandText = fSQLBatch.ToString();

            fConnection.Open();

            fCommand.Connection = fConnection.Connection;
        }
    }
}
