#region license

/*
EasyBuildSQL - is a C# library oriented to help to developers to build sql sentence in differents database engine. 
EasyBuildSQL is developed to .NET Framework.
 
Copyright (C) 2010 - Alejandro Genovesi
http://sourceforge.net/projects/easybuildsql/ 
Contributor : Arturo Martinez

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 
*/

#endregion

using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.ComponentModel;
using System.Collections;
using System.IO;
using MySql.Data.MySqlClient;

namespace EasyBuildSQL
{
    public abstract class ebSQL
    {
        protected DataBaseType fDBType = DataBaseType.MSSQL;
        protected ebConnection fConnection;
        protected DbCommand fCommand;

        protected void PrepareebSQL(string UserName, string Password, string DBName, string Server, DataBaseType DBType)
        {
            fDBType = DBType;

            fConnection = new ebConnection(DBType, UserName, Password, DBName, Server);

            switch (DBType)
            {
                case DataBaseType.MSSQL:
                    {
                        fCommand = new SqlCommand();
                    }
                    break;

                case DataBaseType.MySQL:
                    {
                        fCommand = new MySqlCommand();
                    }
                    break;

                    fCommand.CommandType = CommandType.Text;
            }
        }


        public ebSQL(string UserName, string Password, string DBName, string Server, DataBaseType DBType)
        {
            PrepareebSQL(UserName, Password, DBName, Server, DBType);
        }

        public ebSQL(ConnectionCredentials Credentials)
        {
            PrepareebSQL(Credentials["UserName"], Credentials["Password"], Credentials["DBName"], Credentials["Server"], Credentials.ObtainDBType());
        }

        protected string fErrorSQL;
        public string ErrorSQL
        {
            get
            {
                return fErrorSQL;
            }
        }

        public abstract bool Execute();

        public void Clear()
        {
            Initialize();
        }

        protected virtual void Initialize()
        {
            fCommand.Connection = null;
            fCommand.CommandText = "";
            fCommand.Parameters.Clear();
        }
    }

    public abstract class ebDataModify : ebSQL
    {
        protected string fTable;
        protected DataModify fSentencia = null;

        public ebDataModify(string Table, string UserName, string Password, string DBName, string Server, DataBaseType DBType)
            : base(UserName, Password, DBName, Server, DBType)
        {
            fTable = Table;
        }

        public ebDataModify(string Table, ConnectionCredentials Credentials)
            : base(Credentials["UserName"], Credentials["Password"], Credentials["DBName"], Credentials["Server"], Credentials.ObtainDBType())
        {
            fTable = Table;
        }

        public virtual void AddValue(string Field, object Value)
        {
            fSentencia.AddValue(Field, Value);
        }

        public void AddField(string Field, string Parameter, DbType Type, object Value, int Large)
        {
            fSentencia.AddField(Field, Parameter, Type, Value, Large);
        }

        public void AddField(string Field, DbType Type, object Value, int Large)
        {
            fSentencia.AddField(Field, Type, Value, Large);
        }

        public void AddField(string Field, DbType Type, object Value)
        {
            fSentencia.AddField(Field, Type, Value);
        }

        public void AddField(string Field, string Parameter, DbType Type, object Value)
        {
            fSentencia.AddField(Field, Parameter, Type, Value);
        }

        public void AddBLOB(string Field, string Parameter, string FileName)
        {
            fSentencia.AddBLOB(Field, Parameter, FileName);
        }

        public void AddBLOB(string Field, string FileName)
        {
            fSentencia.AddBLOB(Field, FileName);
        }

        public void AddBLOB(string Field, string Parameter, Stream Stream)
        {
            fSentencia.AddBLOB(Field, Parameter, Stream);
        }

        public void AddBLOB(string Field, Stream Stream)
        {
            fSentencia.AddBLOB(Field, Stream);
        }

        public void AddTEXT(string Field, string Parameter, string FileName)
        {
            fSentencia.AddTEXT(Field, Parameter, FileName);
        }

        public void AddTEXT(string Field, string FileName)
        {
            fSentencia.AddTEXT(Field, FileName);
        }

        public void AddNULL(string Field)
        {
            fSentencia.AddNULL(Field);
        }

        public void AddGETDATE(string Field)
        {
            fSentencia.AddGETDATE(Field);
        }
    }
}
