#region license

/*
EasyBuildSQL - is a C# library oriented to help to developers to build sql sentence in differents database engine. 
EasyBuildSQL is developed to .NET Framework.
 
Copyright (C) 2010 - Alejandro Genovesi
http://sourceforge.net/projects/easybuildsql/ 
Contributor : Arturo Martinez

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 
*/

#endregion

using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.SqlClient;
using System.Data.Common;

namespace EasyBuildSQL
{
  public class ebStoredProc : ebDataSet
  {
    private string fProcedureName;

    public ebStoredProc(string Procedure, string UserName, string Password, string DBName, string Server, DataBaseType DBType)
        : base(UserName, Password, DBName, Server, DBType)
    {
      fProcedureName = Procedure;
    }

    public ebStoredProc(string Procedure, ConnectionCredentials Credentials)
        : base(Credentials)
    {
        fProcedureName = Procedure;
    }

    public DbParameter AddParameter(string Name, DbType Type, ParameterDirection Direction)
    {
      return CreateParameter(Name, Type, Direction, null, 0);
    }

    public DbParameter AddParameter(string Name, DbType Type)
    {
      return CreateParameter(Name, Type, ParameterDirection.Input, null, 0);
    }

    protected override void Initialize()
    {
        base.Initialize();

      fCommand.CommandText = fProcedureName;
      fCommand.CommandType = CommandType.StoredProcedure;

      if (fDBType == DataBaseType.MSSQL)
        CreateParameter("@RETURN_VALUE", DbType.Int32, ParameterDirection.ReturnValue);
    }

    private void Finish()
    {
      if (!fInited)
          Initialize();
    }

    public override bool Execute()
    {
      Finish();

      try
      {
        fConnection.Open();

        fCommand.Connection = fConnection.Connection;
        fCommand.ExecuteNonQuery();
        fConnection.Close();

        return true;
      }
      catch (Exception e)
      {
        fConnection.Close();
        fErrorSQL = e.Message;

        return false;
      }
    }

    public override DbDataReader OpenDataReader()
    {
      Finish();

      try
      {
        DbDataReader drResult;

        fConnection.Open();

        fCommand.Connection = fConnection.Connection;

        drResult = fCommand.ExecuteReader(CommandBehavior.CloseConnection);

        return drResult;
      }
      catch (Exception e)
      {
        fConnection.Close();
        fErrorSQL = e.Message;

        return null;
      }
    }

    public override DataSet OpenDataSet()
    {
      Finish();

      try
      {
        DataSet dsResult = new DataSet();

        DbDataAdapter Adapter;

        fConnection.Open();

        fCommand.Connection = fConnection.Connection;

        switch (fDBType)
        {
            case DataBaseType.MSSQL:
                {
                    Adapter = new SqlDataAdapter( (SqlCommand)fCommand);
                    Adapter.Fill(dsResult);
                    break;
                }

            case DataBaseType.MySQL:
                {
                    Adapter = new MySql.Data.MySqlClient.MySqlDataAdapter((MySql.Data.MySqlClient.MySqlCommand)fCommand);
                    Adapter.Fill(dsResult);
                    break;
                }
        }
        

        fConnection.Close();

        return dsResult;
      }
      catch (Exception e)
      {
        fConnection.Close();
        fErrorSQL = e.Message;

        return null;
      }
    }
  }
}
